<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="属性名称">
              <el-input placeholder="请输入属性名称" clearable v-model="querys[2].value" maxlength="64"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="控件类型">
              <el-select v-model="querys[0].value" clearable placeholder="请选择控件类型">
                <el-option v-for="item in kjlxList" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="配置类型">
              <el-select v-model="querys[1].value" clearable placeholder="请选择配置类型">
                <el-option v-for="item in TypeList" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="3">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" type="danger" icon="el-icon-delete"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
        <el-button style="margin-left: 10px" icon="el-icon-sort" @click="savePropertyf">保存排序号</el-button>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column prop="code" label="属性编码" show-overflow-tooltip></el-table-column>
        <el-table-column prop="name" label="属性名称" show-overflow-tooltip></el-table-column>
        <el-table-column prop="typeName" label="配置类型" show-overflow-tooltip></el-table-column>
        <el-table-column prop="ctlTypeName" label="控件类型" show-overflow-tooltip></el-table-column>
        <el-table-column prop="isRequired" label="是否必填" show-overflow-tooltip>
          <template slot-scope="scope">
            {{
              scope.row.isRequired == 0
                ? '否'
                : scope.row.isRequired == 1
                  ? '是'
                  : ''
            }}
          </template>
        </el-table-column>
        <el-table-column prop="layout" label="布局" show-overflow-tooltip></el-table-column>
        <el-table-column prop="sn" label="排序" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-input type="number" size="small" min="1" @input="insort(scope.row)" v-model="scope.row.sn">
            </el-input>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <basicExtensionDialog ref="formModal"></basicExtensionDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import basicExtensionDialog from '@/views/Device/resourceManage/components/basicExtensionDialog'
import basicExtension from '@/api/device/basicExtension.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
  name: 'UnitManage',
  components: {
    basicExtensionDialog,
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/base/paramsConf/',
      },
      params: {
        ctlType: null,
        type: null,
      },
      sortList: {},
      TypeList: [],
      kjlxList: [],
      companyType: [],
      companyTypeValue: [],
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'ctlType',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'type',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND',
          value: '',
        },
      ],
    }
  },
  created() {
    this.TypeList = dictUtils.getDictItemsFromCache('pzlx')
    this.kjlxList = dictUtils.getDictItemsFromCache('kjlx')
  },
  mounted() { },
  methods: {
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    insort(val) {
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    },
    savePropertyf() {
      basicExtension.saveProperty(this.sortList, (res) => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: res.message,
            duration: 2000,
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      basicExtension.loadUnit(this.queryParam, (res) => {
        res.rows.sort((a, b) => {
          return a.sn - b.sn
        })
        this.tableData = res.rows
        this.total = res.total
        if (this.tableData.length > 0) {
          this.tableData.forEach((e) => {
            if (e.type) {
              this.TypeList.forEach((t) => {
                if (e.type == t.value) {
                  e.typeName = t.name
                }
              })
            }
            if (e.ctlType) {
              this.kjlxList.forEach((k) => {
                if (e.ctlType == k.value) {
                  e.ctlTypeName = k.name
                }
              })
            }
          })
        }

        this.$set(this.tableData)
        this.loading = false
      })
    },
  },
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
